package com.ruoyi.reportManagement.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 库存总账对象 t_whgenleg
 *
 * @author ruoyi
 * @date 2020-12-25
 */
public class TWhgenleg extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * $column.columnComment
     */
    private Long fId;

    /**
     * 年
     */
    private Long fAccyear;

    /**
     * 月
     */
    private Long fAccmonth;

    /**
     * 客户id,t_corps 中的name
     */
    private Long fCorpid;

    /**
     * 提单号
     */
    private String fMblno;

    /**
     * 原始入库业务编号
     */
    @Excel(name = "原始入库业务编号")
    private String fOriginalbillno;

    /**
     * 库区,显示仓库 库位 库区
     */
    private Long fWarehouseLocationid;

    /**
     * 货物品名,t_goods 中的no或 name，模糊查找选择后，存储f_id，显示name
     */
    private Long fGoodsid;

    /**
     * 业务日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "仓储计费日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fBsdate;

    /**
     * 仓储计费日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "仓储计费日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fChargedate;

    /**
     * 贸易方式,对应t_trademodels name
     */
    private Long fTrademodeid;

    /**
     * 上期件数
     */
    @Excel(name = "上期件数")
    private Long fPreqty;

    /**
     * 仓库
     */
    @Excel(name = "仓库")
    private Long fWarehouseid;

    /**
     * 上期毛重,单位为吨，保留6位小数
     */
    @Excel(name = "上期毛重,单位为吨，保留6位小数")
    private BigDecimal fPregrossweight;

    /**
     * 上期净重,
     */
    @Excel(name = "上期净重,")
    private BigDecimal fPrenetweight;

    /**
     * 入库件数
     */
    @Excel(name = "入库件数")
    private Long fQtyd;

    /**
     * 入库尺码
     */
    @Excel(name = "入库尺码")
    private BigDecimal fVolumnd;

    /**
     * 计费方式(数据字典)
     */
    @Excel(name = "计费方式(数据字典)")
    private Long fBillingway;

    /**
     * 入库毛重
     */
    @Excel(name = "入库毛重")
    private BigDecimal fGrossweightd;

    /**
     * 入库净重
     */
    @Excel(name = "入库净重")
    private BigDecimal fNetweightd;

    /**
     * 出口尺码
     */
    @Excel(name = "出口尺码")
    private BigDecimal fVolumnc;

    /**
     * 出库件数
     */
    @Excel(name = "出库件数")
    private Long fQtyc;

    /**
     * 出库毛重,单位为吨
     */
    @Excel(name = "出库毛重,单位为吨")
    private BigDecimal fGrossweightc;

    /**
     * 结余件数
     */
    @Excel(name = "结余件数")
    private Long fQtyblc;

    /**
     * 结余毛重
     */
    @Excel(name = "结余毛重")
    private BigDecimal fGrossweightblc;

    /**
     * 出库净重
     */
    @Excel(name = "出库净重")
    private BigDecimal fNetweightc;

    /**
     * 结余净重
     */
    @Excel(name = "结余净重")
    private BigDecimal fNetweightblc;

    /**
     * 结余尺码
     */
    @Excel(name = "结余尺码")
    private BigDecimal fVolumnblc;

    /**
     * 箱号
     */
    @Excel(name = "箱号")
    private String fCntrno;

    /**
     * 状态，默认 T ,正常T 停用F 下拉选择
     */
    @Excel(name = "状态，默认 T ,正常T 停用F 下拉选择")
    private String fStatus;

    /**
     * 删除状态
     */
    private String delFlag;

    /**
     * 业务类型(存汉字的，用来选择 产地 规格 品牌)
     */
    @Excel(name = "业务类型(存汉字的，用来选择 产地 规格 品牌)")
    private Long fBusinessType;

    /**
     * 唛头
     */
    @Excel(name = "唛头")
    private String fMarks;

    /**
     * 原始入库日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "原始入库日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fOriginalbilldate;

    /** 库内箱号 */
    @Excel(name = "库内箱号")
    private String fLocalcntrno;

    /**
     * 查询时间区间
     */
    private List<String> orgStorageDate;

    /** 仓库 */
    @Excel(name = "仓库")
    private Long fLocation;
    /**
     * 报关单号
     */
    @Excel(name = "报关单号")
    private String fCustomno;

    /** 是否按照箱号 */
    private Long isCntrno;
    /** 是否按照提单号 */
    private Long isMblno;
    //手机号
    private String fTel;

    private String timeStartBsdate;
    private String timeEndBsdate;

    public Date getfBsdate() {
        return fBsdate;
    }

    public void setfBsdate(Date fBsdate) {
        this.fBsdate = fBsdate;
    }

    public String getfTel() {
        return fTel;
    }

    public void setfTel(String fTel) {
        this.fTel = fTel;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Long getIsMblno() {
        return isMblno;
    }

    public void setIsMblno(Long isMblno) {
        this.isMblno = isMblno;
    }

    public String getfCustomno() {
        return fCustomno;
    }

    public void setfCustomno(String fCustomno) {
        this.fCustomno = fCustomno;
    }

    public Long getfId() {
        return fId;
    }

    public void setfId(Long fId) {
        this.fId = fId;
    }

    public Long getfAccyear() {
        return fAccyear;
    }

    public void setfAccyear(Long fAccyear) {
        this.fAccyear = fAccyear;
    }

    public Long getfAccmonth() {
        return fAccmonth;
    }

    public void setfAccmonth(Long fAccmonth) {
        this.fAccmonth = fAccmonth;
    }

    public Long getfCorpid() {
        return fCorpid;
    }

    public void setfCorpid(Long fCorpid) {
        this.fCorpid = fCorpid;
    }

    public String getfMblno() {
        return fMblno;
    }

    public void setfMblno(String fMblno) {
        this.fMblno = fMblno;
    }

    public String getfOriginalbillno() {
        return fOriginalbillno;
    }

    public void setfOriginalbillno(String fOriginalbillno) {
        this.fOriginalbillno = fOriginalbillno;
    }

    public Long getfWarehouseLocationid() {
        return fWarehouseLocationid;
    }

    public void setfWarehouseLocationid(Long fWarehouseLocationid) {
        this.fWarehouseLocationid = fWarehouseLocationid;
    }

    public Long getfGoodsid() {
        return fGoodsid;
    }

    public void setfGoodsid(Long fGoodsid) {
        this.fGoodsid = fGoodsid;
    }

    public Date getfChargedate() {
        return fChargedate;
    }

    public void setfChargedate(Date fChargedate) {
        this.fChargedate = fChargedate;
    }

    public Long getfTrademodeid() {
        return fTrademodeid;
    }

    public void setfTrademodeid(Long fTrademodeid) {
        this.fTrademodeid = fTrademodeid;
    }

    public Long getfPreqty() {
        return fPreqty;
    }

    public void setfPreqty(Long fPreqty) {
        this.fPreqty = fPreqty;
    }

    public Long getfWarehouseid() {
        return fWarehouseid;
    }

    public void setfWarehouseid(Long fWarehouseid) {
        this.fWarehouseid = fWarehouseid;
    }

    public BigDecimal getfPregrossweight() {
        return fPregrossweight;
    }

    public void setfPregrossweight(BigDecimal fPregrossweight) {
        this.fPregrossweight = fPregrossweight;
    }

    public BigDecimal getfPrenetweight() {
        return fPrenetweight;
    }

    public void setfPrenetweight(BigDecimal fPrenetweight) {
        this.fPrenetweight = fPrenetweight;
    }

    public Long getfQtyd() {
        return fQtyd;
    }

    public void setfQtyd(Long fQtyd) {
        this.fQtyd = fQtyd;
    }

    public BigDecimal getfVolumnd() {
        return fVolumnd;
    }

    public void setfVolumnd(BigDecimal fVolumnd) {
        this.fVolumnd = fVolumnd;
    }

    public Long getfBillingway() {
        return fBillingway;
    }

    public void setfBillingway(Long fBillingway) {
        this.fBillingway = fBillingway;
    }

    public BigDecimal getfGrossweightd() {
        return fGrossweightd;
    }

    public void setfGrossweightd(BigDecimal fGrossweightd) {
        this.fGrossweightd = fGrossweightd;
    }

    public BigDecimal getfNetweightd() {
        return fNetweightd;
    }

    public void setfNetweightd(BigDecimal fNetweightd) {
        this.fNetweightd = fNetweightd;
    }

    public BigDecimal getfVolumnc() {
        return fVolumnc;
    }

    public void setfVolumnc(BigDecimal fVolumnc) {
        this.fVolumnc = fVolumnc;
    }

    public Long getfQtyc() {
        return fQtyc;
    }

    public void setfQtyc(Long fQtyc) {
        this.fQtyc = fQtyc;
    }

    public BigDecimal getfGrossweightc() {
        return fGrossweightc;
    }

    public void setfGrossweightc(BigDecimal fGrossweightc) {
        this.fGrossweightc = fGrossweightc;
    }

    public Long getfQtyblc() {
        return fQtyblc;
    }

    public void setfQtyblc(Long fQtyblc) {
        this.fQtyblc = fQtyblc;
    }

    public BigDecimal getfGrossweightblc() {
        return fGrossweightblc;
    }

    public void setfGrossweightblc(BigDecimal fGrossweightblc) {
        this.fGrossweightblc = fGrossweightblc;
    }

    public BigDecimal getfNetweightc() {
        return fNetweightc;
    }

    public void setfNetweightc(BigDecimal fNetweightc) {
        this.fNetweightc = fNetweightc;
    }

    public BigDecimal getfNetweightblc() {
        return fNetweightblc;
    }

    public void setfNetweightblc(BigDecimal fNetweightblc) {
        this.fNetweightblc = fNetweightblc;
    }

    public BigDecimal getfVolumnblc() {
        return fVolumnblc;
    }

    public void setfVolumnblc(BigDecimal fVolumnblc) {
        this.fVolumnblc = fVolumnblc;
    }

    public String getfCntrno() {
        return fCntrno;
    }

    public void setfCntrno(String fCntrno) {
        this.fCntrno = fCntrno;
    }

    public String getfStatus() {
        return fStatus;
    }

    public void setfStatus(String fStatus) {
        this.fStatus = fStatus;
    }

    public String getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public Long getfBusinessType() {
        return fBusinessType;
    }

    public void setfBusinessType(Long fBusinessType) {
        this.fBusinessType = fBusinessType;
    }

    public String getfMarks() {
        return fMarks;
    }

    public void setfMarks(String fMarks) {
        this.fMarks = fMarks;
    }

    public Date getfOriginalbilldate() {
        return fOriginalbilldate;
    }

    public void setfOriginalbilldate(Date fOriginalbilldate) {
        this.fOriginalbilldate = fOriginalbilldate;
    }

    public List<String> getOrgStorageDate() {
        return orgStorageDate;
    }

    public void setOrgStorageDate(List<String> orgStorageDate) {
        this.orgStorageDate = orgStorageDate;
    }

    public Long getfLocation() {
        return fLocation;
    }

    public void setfLocation(Long fLocation) {
        this.fLocation = fLocation;
    }

    public Long getIsCntrno() {
        return isCntrno;
    }

    public void setIsCntrno(Long isCntrno) {
        this.isCntrno = isCntrno;
    }

    public String getTimeStartBsdate() {
        return timeStartBsdate;
    }

    public void setTimeStartBsdate(String timeStartBsdate) {
        this.timeStartBsdate = timeStartBsdate;
    }

    public String getTimeEndBsdate() {
        return timeEndBsdate;
    }

    public void setTimeEndBsdate(String timeEndBsdate) {
        this.timeEndBsdate = timeEndBsdate;
    }

    public String getfLocalcntrno() {
        return fLocalcntrno;
    }

    public void setfLocalcntrno(String fLocalcntrno) {
        this.fLocalcntrno = fLocalcntrno;
    }

    @Override
    public String toString() {
        return "TWhgenleg{" +
                "fId=" + fId +
                ", fAccyear=" + fAccyear +
                ", fAccmonth=" + fAccmonth +
                ", fCorpid=" + fCorpid +
                ", fMblno='" + fMblno + '\'' +
                ", fOriginalbillno='" + fOriginalbillno + '\'' +
                ", fWarehouseLocationid=" + fWarehouseLocationid +
                ", fGoodsid=" + fGoodsid +
                ", fChargedate=" + fChargedate +
                ", fTrademodeid=" + fTrademodeid +
                ", fPreqty=" + fPreqty +
                ", fWarehouseid=" + fWarehouseid +
                ", fPregrossweight=" + fPregrossweight +
                ", fPrenetweight=" + fPrenetweight +
                ", fQtyd=" + fQtyd +
                ", fVolumnd=" + fVolumnd +
                ", fBillingway=" + fBillingway +
                ", fGrossweightd=" + fGrossweightd +
                ", fNetweightd=" + fNetweightd +
                ", fVolumnc=" + fVolumnc +
                ", fQtyc=" + fQtyc +
                ", fGrossweightc=" + fGrossweightc +
                ", fQtyblc=" + fQtyblc +
                ", fGrossweightblc=" + fGrossweightblc +
                ", fNetweightc=" + fNetweightc +
                ", fNetweightblc=" + fNetweightblc +
                ", fVolumnblc=" + fVolumnblc +
                ", fCntrno='" + fCntrno + '\'' +
                ", fStatus='" + fStatus + '\'' +
                ", delFlag='" + delFlag + '\'' +
                ", fBusinessType=" + fBusinessType +
                ", fMarks='" + fMarks + '\'' +
                ", fOriginalbilldate=" + fOriginalbilldate +
                ", fLocalcntrno='" + fLocalcntrno + '\'' +
                ", orgStorageDate=" + orgStorageDate +
                ", fLocation=" + fLocation +
                ", isCntrno=" + isCntrno +
                ", timeStartBsdate='" + timeStartBsdate + '\'' +
                ", timeEndBsdate='" + timeEndBsdate + '\'' +
                ", fCustomno='" + fCustomno + '\'' +
                '}';
    }
}

